==> foundation-ui-components-1.26.1.tgz: package/src/common/carousal/specs/NsCarousal.spec.tsx <==
import { render, screen, fireEvent } from '@/test-utils/index';
import { NsCarousal } from '@/common/';

const mockEntries = [
    { id: 1, title: 'First entry' },
    { id: 2, title: 'Second entry' },
    { id: 3, title: 'Third entry' },
    { id: 4, title: 'Fourth entry' },
    { id: 5, title: 'Fifth entry' },
];

const mockRenderEntry = (entry: any, index: number) => {
    return <div key={index}>{entry.title}</div>;
};
const mockAllEntryLink = '/view-all';
const mockSettings = {
    slidesToShow: 2,
    slidesToScroll: 1,
};
describe('NsCarousal', () => {
    it('should have prev and next chevron', () => {
        render(
            <NsCarousal
                entries={[]}
                renderEntry={mockRenderEntry}
                allEntryLink={mockAllEntryLink}
                settings={mockSettings}
            />
        );
        const prevSvg = screen.getByTestId('arrowLeft');
        const nextSvg = screen.getByTestId('arrowRight');
        expect(prevSvg).toBeInTheDocument();
        expect(nextSvg).toBeInTheDocument();
    });

    it('should view all link with correct href and slides', () => {
        const { container } = render(
            <NsCarousal
                entries={mockEntries}
                renderEntry={mockRenderEntry}
                allEntryLink={mockAllEntryLink}
                settings={mockSettings}
            />
        );

        const viewAllLink = screen.getByRole('link', { name: /view all/i });
        const slides = container.querySelectorAll('.slick-slide');

        expect(viewAllLink).toBeInTheDocument();
        expect(viewAllLink).toHaveAttribute('href', mockAllEntryLink);
        expect(slides).toHaveLength(mockEntries.length);
        expect(slides[0]).toHaveTextContent('First entry');
        expect(slides[1]).toHaveTextContent('Second entry');
        expect(slides[2]).toHaveTextContent('Third entry');
    });

    it('should change slides when clicking on prev or next buttons', () => {
        const { container } = render(
            <NsCarousal
                entries={mockEntries}
                renderEntry={mockRenderEntry}
                allEntryLink="/view-all"
                settings={mockSettings}
            />
        );

        let currentSlide = container.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('0');

        /* this is library's button, not our button, it is used for changing slides,
      clicking svg is not making any slide change in this test */
        const nextButton = screen.getByRole('button', { name: /next/i });
        fireEvent.click(nextButton);

        let slickTrack = container.querySelector('.slick-track');
        currentSlide = slickTrack!.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('1');

        /* below code is commented because prev button is not working as expected in tests */
        // const prevButton = screen.getByRole('button', { name: /prev/i })
        // fireEvent.click(prevButton)
        // screen.debug(prevButton)
        // let slickList = container.querySelector('.slick-list')
        // currentSlide = slickList!.querySelector('.slick-slide.slick-current')
        // expect(currentSlide!.attributes['data-index' as any].value).toEqual('0')

        // // currentSlide = screen.getByText(mockEntries[0].title)
        // currentSlide = slickTrack!.querySelector('.slick-slide.slick-current')
        // expect(currentSlide!.attributes['data-index' as any].value).toEqual('0')
    });

    it('should change slides when clicking on prev or next buttons', () => {
        const { container } = render(
            <NsCarousal
                entries={mockEntries}
                renderEntry={mockRenderEntry}
                allEntryLink="/view-all"
                settings={mockSettings}
            />
        );
        let next = container.querySelector('.carousal-next-button');
        let prev = container.querySelector('.carousal-prev-button');
        fireEvent.click(next!);
        fireEvent.click(prev!);
    });
});

==> foundation-ui-components-1.30.1.tgz: package/src/common/carousal/specs/NsCarousal.spec.tsx <==
import { ReactElement } from 'react';

import { NsCarousal } from '@/common/';
import {
    fireEvent,
    render,
    screen,
} from '@/test-utils/index';

const mockEntries = [
    { id: 1, title: 'First entry' },
    { id: 2, title: 'Second entry' },
    { id: 3, title: 'Third entry' },
    { id: 4, title: 'Fourth entry' },
    { id: 5, title: 'Fifth entry' },
];

const mockRenderEntry = (entry: any, index: number): ReactElement => {
    return <div key={index}>{entry.title}</div>;
};
const mockAllEntryLink = '/view-all';
const mockSettings = {
    slidesToShow: 2,
    slidesToScroll: 1,
};
describe('NsCarousal', () => {
    it('should have prev and next chevron', () => {
        render(
            <NsCarousal
                entries={[]}
                renderEntry={mockRenderEntry}
                allEntryLink={mockAllEntryLink}
                settings={mockSettings}
            />
        );
        const prevSvg = screen.getByTestId('arrowLeft');
        const nextSvg = screen.getByTestId('arrowRight');
        expect(prevSvg).toBeInTheDocument();
        expect(nextSvg).toBeInTheDocument();
    });

    it('should view all link with correct href and slides', () => {
        const { container } = render(
            <NsCarousal
                entries={mockEntries}
                renderEntry={mockRenderEntry}
                allEntryLink={mockAllEntryLink}
                settings={mockSettings}
            />
        );

        const viewAllLink = screen.getByRole('link', { name: /view all/i });
        const slides = container.querySelectorAll('.slick-slide');

        expect(viewAllLink).toBeInTheDocument();
        expect(viewAllLink).toHaveAttribute('href', mockAllEntryLink);
        expect(slides).toHaveLength(mockEntries.length);
        expect(slides[0]).toHaveTextContent('First entry');
        expect(slides[1]).toHaveTextContent('Second entry');
        expect(slides[2]).toHaveTextContent('Third entry');
    });

    it('should change slides when clicking on prev or next buttons', () => {
        const { container } = render(
            <NsCarousal
                entries={mockEntries}
                renderEntry={mockRenderEntry}
                allEntryLink="/view-all"
                settings={mockSettings}
            />
        );

        let currentSlide = container.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('0');

        /* this is library's button, not our button, it is used for changing slides,
      clicking svg is not making any slide change in this test */
        const nextButton = screen.getByRole('button', { name: /next/i });
        fireEvent.click(nextButton);

        let slickTrack = container.querySelector('.slick-track');
        currentSlide = slickTrack!.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('1');

        /* below code is commented because prev button is not working as expected in tests */
        // const prevButton = screen.getByRole('button', { name: /prev/i })
        // fireEvent.click(prevButton)
        // screen.debug(prevButton)
        // let slickList = container.querySelector('.slick-list')
        // currentSlide = slickList!.querySelector('.slick-slide.slick-current')
        // expect(currentSlide!.attributes['data-index' as any].value).toEqual('0')

        // // currentSlide = screen.getByText(mockEntries[0].title)
        // currentSlide = slickTrack!.querySelector('.slick-slide.slick-current')
        // expect(currentSlide!.attributes['data-index' as any].value).toEqual('0')
    });

    it('should change slides when clicking on prev or next buttons', () => {
        const { container } = render(
            <NsCarousal
                entries={mockEntries}
                renderEntry={mockRenderEntry}
                allEntryLink="/view-all"
                settings={mockSettings}
            />
        );
        let next = container.querySelector('.carousal-next-button');
        let prev = container.querySelector('.carousal-prev-button');
        fireEvent.click(next!);
        fireEvent.click(prev!);
    });
});
